@@ -1,5 +1,4 @@
 # -*- perl -*-
-
 #
 # Author: Gisbert W. Selke, TapirSoft Selke & Selke GbR.
 #
@@ -9,13 +8,11 @@
 #
 # Mail: gws@cpan.org
 #
-
-
 package Map::Tube::KoelnBonn;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =encoding utf8
 
@@ -54,10 +51,17 @@ All interesting methods are provided by the role L<Map::Tube>.
 =head2 CONSTRUCTOR
 
     use Map::Tube::KoelnBonn;
-    my $tube = Map::Tube::KoelnBonn->new;
+    my $tube = Map::Tube::KoelnBonn->new();
 
-This will read the tube information from the shared file F<koelnbonn-map.xml>,
-which is part of the distribution.
+The only argument, C<xml>, is optional; if specified, it should be a code ref
+to a function that returns either the path the XML map file, or a string
+containing this XML content. The default is the path to F<koelnbonn-map.xml>
+that is a part of this distribution. For further information see L<Map::Tube>.
+
+=head2 xml()
+
+This read-only accessor returns whatever was specified as the XML source at
+construction.
 
 =head1 ERRORS
 
